@@ -1,6 +1,6 @@
 import time
 import pdb
-from gi.repository import Notify
+# from gi.repository import Notify
 from subprocess import call
 
 
@@ -89,7 +89,7 @@ def display_alert(args):
     alert_title = args[u'alert_title']
     alert_message = args[u'alert_message']
     urgency = args[u'urgency']
-    msg=Notify.Notification.new (alert_title, alert_message, u"dialog-information")
+    # msg=Notify.Notification.new (alert_title, alert_message, u"dialog-information")
     # msg.show ()
     cmd = construct_notification_command(alert_title, alert_message, urgency)
 #    pdb.set_trace()
@@ -111,9 +111,41 @@ def init(args): # in_my_username, in_seconds_listen_channel):
     my_username = args[u"username"]
     seconds_listen_channel = args[u"monitor_time"]
 
-Notify.init (u"Notify Init")
+# Notify.init (u"Notify Init")
 
 seconds_listen_channel = 5*60 # seconds
 my_username = u"fenton"
 
 
+#### HELPERS
+
+def display_actions(actions):
+    print( "RESPONSE:" )
+#    pdb.set_trace()
+    for action in actions:
+        print( "  ==> " + action["action"].__name__ )
+        action_args = action["arguments"]
+        for param, value in action_args.items():
+            print ( "\t+ " + param + ": " + value )
+
+def display_incoming_message(im):
+    global start_time
+    elapsed = time.time() - start_time
+    print( "INCOMING MESSAGE: +" + str(round(elapsed)) + "(s)" )
+    print( "\t[from]: "  + im["from_who"] + "   [to me]: " + str(im["to_me"]) + "   [channel]: " + im["channel"])
+    print( "\t[message]: " + im["message"])
+
+def display_state():
+    print("MONITORING CHANNELS:")
+    for channel, monitored_since in imp.monitored_channels.items():
+        elapsed = time.time() - monitored_since
+        print ( "\t" + channel + ", for: " + str(round(elapsed)) + " of " + str(imp.seconds_listen_channel) + "(s)" )
+
+def printall(incoming_message, response_actions):
+    display_incoming_message(incoming_message)
+    display_actions(response_actions)
+    display_state()
+
+def print_sep(dur):
+    print("-------------------------------")
+    time.sleep(dur)
